# stimulus_generation
Folder containing code to generate stimuli for 'Evidence for a shared cognitive mechanism underlying relative rhythmic and melodic perception'.  

### Usage
To create new stimuli, run the 'Stimuli.ipynb' notebook code fields, after setting up al dependencies. 

- 1st field<br />
Decoration

- 2nd field<br />
Imports

- 3rd field<br />
Parameters used for stimulus creation.<br /><br />
_**measures**_ defines number of measures stimuli will have. _Required format_: integer.<br />
_**tempi**_ defines range of tempi stimuli (in beats per minute) will be created with. _Required format_: List of integers.<br />
_**referents**_ defines style of referents stimuli will be created with. _Required format_: List of integers, with potential values 0 (no referent), 1 (weak referent) and 2 (strong referent).<br />
_**rhythm_interval_manipulations**_ defines manipulations that will be applied to every possible interval for the rhythm stimuli. Unit of manipulation is semitones. _Required format_: List of floats<br />
_**melody_interval_manipulations**_ defines manipulations that will be applied to every possible interval for the melody stimuli. Unit of manipulation is quarternote durations. _Required format_: List of floats<br />

- 4th field<br />
Defines the accept-decorator. This decorater is used to limit the type and contents of arguments used in all generation functions. The _value_dict_ variable can be used to add specific argument contents. _int_zero_list_ contains arguments that require an integer value larger than 0.

- 5th field<br />
Pentatonic variables containing information necessary for random and weighted generation of the melodies.

- 6th field<br />
Contains all functions responsible for stimuli generation. 

- **7th field**<br />
Runs the _create_stimuli()_ function, and as such creates all stimuli requested according to arguments provided. See the _create_stimuli()_ declaration for default arguments.<br /><br />
_**itter**_ Parameter used to track the number of iterations per mode executed. Every iteration creates a new target pattern. _Required format_: Integer.<br />
_**measures**_ Parameter used to declare the number of measures (4/4 meter) per stimulus per repeat. _Required format_: Integer.<br />
_**tempi**_ parameter used to declare the range of tempi stimuli (in beats per minute) will be created with. _Required format_: List of integers.<br />
_**referents**_ Parameter used to defines style of referents stimuli will be created with. _Required format_: ist of integers, range of 0 up to and including 2.<br />
_**random_intervals**_ Parameter used to declare the style of target generation. 0 for weighted randomised generation. 1 for random. Only melody can be generated using weighted randomisation. _Required format_: Integer, 0 or 1.<br />
_**interval_manipulations**_ Parameter used to declaremanipulations that will be applied to every possible interval for stimuli. _Required format_: List of floats.<br />
_**mode**_ Parameter used to declare the type of stimulus this iteration will generate, _rhythm_ or _melody_. _Required format_: String, either 'rhythm' or 'melody'.<br />
_**repeats**_ Parameter used to declare the number of repeats of the total pattern stimuli will be generated with. _Required format_: Integer.<br /><br />
2nd loop (Stimuli selection) will automatically move a limited set of stimuli to a a 'stimuli' folder in their respective 'mode-folder'. 


### Structure
Main folder contains notebooks for stimuli generation (Stimuli.ipynb) and dependencies (latest versions before submission) in conda_environment.json. Additional folders are generated by the notebook code. 

##### _**rhythm**_ 
Folder contains all subfolders rhythm related. Also contains csv delineating details for each stimulus created. 

- midi<br />
Contains subfolders with all midi versions of all created rhythm stimuli.

- wav<br />
Contains subfolders with all midi versions of all created rhythm stimuli.

- stimuli<br />
Contains rhythm stimuli (wav) selected, and related CSV files, for actual presentation during the experiment and pilot.

##### _**melody**_
Folder contains all subfolders melody related. Also contains csv delineating details for each stimulus created.

- midi<br />
Contains subfolders with all midi versions of all created melody stimuli.

- wav<br />
Contains subfolders with all midi versions of all created melody stimuli.

- stimuli<br />
Contains melody stimuli (wav) selected, and related CSV files, for actual presentation during the experiment and pilot.

- referents<br />
Contains wav files of referent-intermediates created. The referents are integerated into the appropriate stimuli (wav).

#### CSV Output from code
_**counter**_ Stimulus generation number within current iteration. <br />
_**contour_impact**_ Contour impact of current manipulation. 0 for non-contour change. 1 for contour change.<br />
_**position**_ Interval number to which manipulation is applied. Note, position does not equal index, position 1 refers to the actual 1st interval. <br />
_**framework_score**_ Score which refers to whether the manipulated stimulus is 'in-framework'. For rhythms, this score is equal to the monophonic Longuet-Higgins & Lee (1984) syncopation score. For melody, the means whether the stimulus is in (pentatonic) key: 0 for out of key and 1 for in key.<br />
_**lowest_framework_score**_ Lowest syncopation score possible for this particular interval pattern. This score is only relevant for rhythm stimuli with referent 0. <br />
_**lowest_offset**_ Interval offset for the entire pattern that led to the lowest syncopation score. <br />
_**seed**_ Seed used to randomised generation of the melody. This seed is the root of the pentatonic key. Seed refers to the midi number of the note (see: https://www.inspiredacoustics.com/en/MIDI_note_numbers_and_center_frequencies), and is randomly chosen from the 4th ocatave.<br />
_**interval_manipulation**_ Manipulation applied to interval with position x (see position value). Manipulation unit is quarternote durations for rhythm and semitones for melody. <br />
_**tempo**_ Tempo of the stimulus (in beats per minute).<br />
_**referents**_ Style of referent within stimulus. 0 is no referent, 1 is a weak referent, 2 is a strong referent. <br />
_**repeats**_ Number of repeats of the total stimulus pattern.<br />
_**created**_ Creation date and time of the stimulus.<br />
_**interval n**_ Interval size of interval n. Interval unit is quarternote durations for rhythm and semitones for melody. 